@@ -38,9 +38,12 @@ def set_theme(filename, cs_file, vte, restore=False):
                            path.join(config.WALL_DIR, 'current.css'))
         pywal.export.color(colors, 'shell',
                            path.join(config.WALL_DIR, 'current.sh'))
+        pywal.export.color(colors, 'xresources',
+                           path.join(config.WALL_DIR, 'current.Xres'))
 
         init_file = open(path.join(config.WALL_DIR, 'wp_init.sh'), 'w')
-        init_file.writelines(['#!/bin/bash\n', 'wpg -r -s ' +
+        wpg_string = 'wpg -rvs ' if vte else 'wpg -rs '
+        init_file.writelines(['#!/bin/bash\n', wpg_string +
                               filename + ' ' + cs_file])
         init_file.close()
         Popen(['chmod', '+x', path.join(config.WALL_DIR, 'wp_init.sh')])
@@ -93,22 +96,10 @@ def shuffle_colors(filename):
         print('ERR:: file not available')
 
 
-def auto_adjust_colors(filename):
+def auto_adjust_theme(filename):
     try:
         color_list = color.get_color_list(filename)
-        color8 = color_list[0:1][0]
-        if not config.wpgtk.getboolean('light_theme'):
-            color8 = [color.add_brightness(color8, 18)]
-            color_list = color_list[:8:]
-            color_list += color8
-            color_list += [color.add_brightness(x, 50)
-                           for x in color_list[1:8:]]
-        else:
-            color8 = [color.reduce_brightness(color8, 18)]
-            color_list = color_list[:8:]
-            color_list += color8
-            color_list += [color.reduce_brightness(x, 50)
-                           for x in color_list[1:8:]]
+        color_list = color.auto_adjust_colors(color_list)
         sample.create_sample(color_list,
                              f=path.join(config.SAMPLE_DIR,
                                          (filename + '.sample.png')))
